@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: types.h 29603 2005-07-31 16:10:46Z cjwatson $
+ * $Id: types.h 36508 2006-04-19 11:21:21Z waldi $
  */
 
 #ifndef DEBIAN_INSTALLER__TYPES_H
@@ -33,6 +33,12 @@
  * @{
  */
 
+/**
+ * Compare key1 and key2
+ * @param key1 first key
+ * @param key2 second key
+ */
+typedef int di_compare_func (const void *key1, const void *key2);
 /**
  * Checks the equality of key1 and key2
  * @param key1 first key
